# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['volumizer']

package_data = \
{'': ['*']}

install_requires = \
['biotite>=0.37.0,<0.38.0', 'pyntcloud>=0.1.5,<0.2.0']

setup_kwargs = {
    'name': 'volumizer',
    'version': '0.1.0',
    'description': 'Search the RCSB for occluded volumes like cavities, pockets, and pores.',
    'long_description': '`volumizer` discovers and annotates occluded volumes in proteins including:\n- Cavities: Volumes within a protein that do not make any contacts with bulk solvent. Useful for e.g. carrying cargo.\n- Pockets: Volumes on the protein surface that make a single contact with bulk solvent.  Useful for e.g. ligand binding or catalysis.\n- Pores: Volumes connecting two bulk solvent surfaces.  Useful for e.g. filtering solutes.\n- Hubs: Volumes connecting more than two bulk solvent surfaces.  Maybe useful for slow release of cargo...\n\n# Example Identified Volume\n\nHere is shown an example pore identified and annotated (red) in PDB 4JPN (green).\n![image](images/pore_annotation.png)\n\nThe same pore volume annotated (red) shown as a slice through the protein (grey).\n![image](images/pore_slice.png)\n\n# Installation\nTODO: replace this with pip install once package is ready\n`Porate` was written to use python 3.9.\n\n## Python Package Installation Using Poetry\n`Porate` can be installed and run from a virtual environment using `poetry`, a widely used python virtual environment manager.\n\n```bash\npoetry install\n```\n\n## Manually Python Package Installation\nIf you wish to install outside of a poetry managed virtual environment, the 3rd party python packages that need to be installed are:\n\n- typer\n- biopython\n- pyntcloud\n- requests\n- progressbar\n\n## Compiling C Source\nSeveral under-the-hood functions are implemented in both python and C.  If the C versions are not compiled performance will be reduced.\nTo compile them:\n```bash\n./source/compile_c_libs.sh\n```\n\n# Usage\nTODO: show single example CLI with resolution changes\n\n`Porate` can be invoked from the command-line or imported and used within your own python scripts.\n\n## CLI Usage\nNote that when first run `porate` will need to download the RCSB components datafile from the public\nRCSB database, which is used to optionally clean structures of extraneous atoms (see Flags below).\n\nThe CLI can be used with 4 different inputs.\n\n1. A single PDB ID can be supplied.\n```bash\npython porate 4JPN\n```\n2. A batch of PDB IDs can be supplied in a text file, one per line.\n```bash\npython porate <path-to-my-text-file>\n```\n3. A local PDB file can be supplied.\n```bash\npython porate <path-to-my-file>\n```\n4. A batch of PDB files from a directory can be supplied.\n```bash\npython porate <path-to-my-dir-of-PDBs>\n```\n\n### Flags\n`resolution` the length of the sides of the voxels constructed.  3 Angstroms is the default.  Smaller values\nwill result in higher resolution structures but will take longer to annotate.\n\n`non-protein` should non-protein atoms be kept as part of the structure?  False by default which means the structure is\ncleaned of explicit waters, salts, ligands, etc.. leaving only protein atoms (both natural and non-natural).\n\n`jobs` how many threads to use for computation.  This only applies when multiple PDBs are being annotated in which\ncase they are trivially paralellized across threads.\n\n## Python Package Usage\nPENDING DOCUMENTATION\n\n\n# How It Works\n`Porate` identifies hydrated volumes in a protein structure that are not fully solvent exposed, e.g. a binding pocket.\nIt then computes the volume and dimensions of these volumes and outputs that information along with an annotated \nversion of the input PDB showing where the volumes are (which can be visualized in e.g. Pymol).\n\n## Identifying hydrated volumes\n1. A large voxel-grid is built around the atoms of the protein or other structure supplied.\n2. All voxels within a van der Waals radius of a protein or other atom is flagged as being `non-solvent`\n3. Remaining `solvent` atoms are then broken into two groups: `bulk solvent` and `occluded volumes`\n   This is done by tracing a vector along each ordinal axis from a given voxel and if 2 or more of these vectors would\n   cross a `non-solvent` voxel, then the query voxel is identified as an `occluded volume` to be further analyzed\n   otherwise it is considered `bulk solvent`\n   The intention is to identify points on the grid that are outside the protein as `bulk solvent`\n4. All `occluded volume` voxels are then grouped into a number of continuous volumes\n5. For each continous volume the number of distinct surfaces that contact `bulk solvent` voxels is computed and used\n   to indicate the volume type:\n   0 surfaces interacting with solvent: cavity\n   1 surface interacting with solvent: pocket\n   2 surfaces interacting with solvent: pore\n   3+ surfaces interacting with solvent: hub\n\n## Annotations\n\n### Pandas DataFrame\nAnnotations are given as a pandas data frame saved as a .json file.  The annotation lists all hydrated volumes ordered by\ntotal volume, giving the type of volume, and dimensions.\n\n### PDB File\nThe input PDB file will be annotated by adding `atoms` to represent the hydrated volumes.  The ATOM entries\ncontain several points of information about the volume from which they come:\n\nType of volume: the residue name encodes the type of volume in 3-letter code\nOCC for occluded\nCAV for cavity\nPOK for pocket\nPOR for pore\nHUB for hub\n\nSurface of the hydrated volume that interacts with bulk solvent: this is indicated by a B-factor of 50.0, whereas\nthe remainder of the volume (that does not interact with the bulk solvent) has a value of 0.0.\n\nAll `atoms` of a particular volume are grouped under the same residue number.\n\nFinally, several remarks are added:\nAt the beginning of the file the rotation and translation matrices used to transform the input before voxelization are given.\nAt the end of the file including the resolution used for the analysis, as well as the total volume and dimensions of significant volumes.\n',
    'author': 'Aron Broom',
    'author_email': 'broomsday@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
